(v1.11.1)=
### 1.11.1 {small}`2025-03-31`

#### Bug fixes

- Fix compatibility with IPython 9 {smaller}`P Angerer` ({pr}`3499`)
- Prevent too-low matplotlib version from being used {smaller}`P Angerer` ({pr}`3534`)

#### Features

- Allow `covariance_eigh` as a solver option for {func}`~scanpy.pp.pca` with {class}`dask.array.Array` dense data {smaller}`ilan-gold` ({pr}`3528`)

#### Performance

- Speed up wilcoxon rank-sum test with numba {smaller}`G Wu` ({pr}`3529`)
